<?php declare(strict_types = 0);
/*
** Glaber
** Copyright (C) 2001-2024 Glaber
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
**/

$content = new CDiv();

$url_table = createUrlTable($data);

$form = (new CForm('ruleedit'))
	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, CCsrfTokenHelper::get('acknowledge')))->removeId())
	->addVar('dashboardid', $data['dashboardid'])
	->addVar('widgetid', $data['widgetid'])
	->addVar('elementid', $data['elementid']);

$edit_form = (new CFormGrid())
	->addItem([
		(new CLabel(_('Assing object'), 'Assign object')),
		(new CRadioButtonList('bind_object_type', (int) $data['fields']['bind_object_type']))
			->addValue(_('None'), 0)
			->addValue(_('Host'), 1)
			->addValue(_('HostGroup'), 2)
			->addValue(_('Item'), 3)
			->addValue(_('Trigger'), 4)
			->setModern(true)])
	->addItem([
		(new CLabel(_('Host'), 'hostid'))
			->addStyle('margin-right: 5px;')
			->addClass('host_fields'),
		(new CFormField(	
		(new CMultiSelect([
			'name' => 'hostid',
			'object_name' => 'hosts',
			'data' => $data['fields']['hosts'] ? $data['fields']['hosts'] : [],
			'multiple' => false,
			'popup' => [
				'parameters' => [
					'srctbl' => 'hosts',
					'srcfld1' => 'hostid',
					'dstfrm' => $form->getName(),
					'dstfld1' => 'hostid',
					'monitored_hosts' => true,
					'with_items' => true
				]
			]
		]))
			->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
		))	->addClass('host_fields')
	])
	->addItem([
		(new CLabel(_('Host group'), 'group'))
			->addClass('group_fields'),
		(new CFormField(
			(new CMultiSelect([
				'name' => 'groupid',
				'object_name' => 'hostGroup',
				'data' => $data['fields']['groups'] ? $data['fields']['groups'] : [],
				'multiple' => false,
				'popup' => [
					'parameters' => [
						'srctbl' => 'host_groups',
						'srcfld1' => 'groupid',
						'dstfrm' => $form->getName(),
						'dstfld1' => 'groupid',
						'editable' => true,
					]
				]
			]))
			->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
			->setAriaRequired()
		)) ->addClass('group_fields')
	])
	->addItem([ (new CLabel(_('Trigger'), 'trigger'))->addClass('trigger_fields'),
		(new CFormField(
			(new CMultiSelect([
				'name' => 'triggerid',
				'object_name' => 'triggers',
				'data' => $data['fields']['triggers'] ? $data['fields']['triggers'] : [],
	//			'multiple' => false,
				'popup' => [
					'parameters' => [
						'srctbl' => 'triggers',
						'srcfld1' => 'triggerid',
						'dstfrm' => $form->getName(),
						'dstfld1' => 'triggerid',
						'monitored_hosts' => true,
						'with_monitored_triggers' => true
					]
				]
			]))
			->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
			
			
		)) ->addClass('trigger_fields')
	])
	->addItem([ (new CLabel(_('Item'), 'item'))->addClass('item_fields'),
		(new CFormField(
			(new CMultiSelect([
			'name' => 'itemid',
			'object_name' => 'items',
			'data' => $data['fields']['items'] ? $data['fields']['items'] : [],
			'multiple' => false,
			'styles' => [
				'display' => 'inline-flex'
			],
			'popup' => [
				'parameters' => [
				'srctbl' => 'items',
				'srcfld1' => 'itemid',
				'srcfld2' => 'name',
				'dstfrm' => $form->getName(),
				'dstfld1' => 'itemid',
				'numeric' => '1',
				'real_hosts' => true //!$data['is_template']
				]
			]
			]))
				->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
			))->addClass('item_fields')])
	->addItem([
		(new CLabel(_('Change fill:'), 'change_fill_max_severity'))->addClass('change_fill_max_severity'),
		(new CFormField(
			(new CCheckBox('fill_max_severity'))
			->setLabel(_('to max object severity color'))
			->setChecked($data['fields']['fill_max_severity'])
		))->addClass('change_fill_max_severity')
	])
	->addItem([
		(new CLabel(_('URLs'), 'urls'))->addClass('url_table'),
		(new CFormField(
			$url_table
		))->addClass('url_table')
	]);
	

$form->addItem($edit_form);	

$content
	->addItem(
		
		(new CScriptTag(
		
		(new CRow([
			(new CTextBox('urls[#{id}][name]'))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH),
			(new CTextBox('urls[#{id}][url]'))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
			(new CCol(
				(new CButton(null, _('Remove')))
					->onClick('$("#url-row-#{id}").remove();')
					->addClass(ZBX_STYLE_BTN_LINK)
			))->addClass(ZBX_STYLE_NOWRAP)
		]))->setId('url-row-#{id}')
		)
		)->setAttribute('type',"text/x-jquery-tmpl")
		->setAttribute('id',"url-tpl")
	)
	->addItem($form);


$output = [
	'header' => "Edit object rule",
	'body' => $content->toString(),
    'buttons' => [[
				'title' => _('Update'),
				'class' => 'js-update',
				'keepOpen' => true,
				'isSubmit' => true,
				'action' => 'widget_rule_edit.submitRule(overlay);'
			],
		],
		
	'script_inline' => getPagePostJs().$this->readJsFile('widget.rule.edit.js.php').
			'widget_rule_edit.init();'
];

echo json_encode($output);


function createUrlTable(array &$data) {
	$url_table = (new CTable())
		->setAttribute('style', 'width: 100%;')
		->setHeader([_('Name'), _('URL'),  _('Action')]);
		
	if (empty($data['fields']['urls'])) 
		$data['urls'][] = ['name' => '', 'url' => ''];
	
	$i = 0;

	foreach ($data['fields']['urls'] as $url) {

		$url_table->addRow(
			(new CRow([
				(new CTextBox('urls['.$i.'][name]', $url['name']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH),
				(new CTextBox('urls['.$i.'][url]', $url['url']))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
			
				(new CCol(
					(new CButton(null, _('Remove')))
						->onClick('$("#url-row-'.$i.'").remove();')
						->addClass(ZBX_STYLE_BTN_LINK)
				))->addClass(ZBX_STYLE_NOWRAP)
			]))->setId('url-row-'.$i)
		);
		$i++;
	}

	$url_table->addRow(
		(new CCol(
			(new CButton(null, _('Add')))
				->setId('add-url')
				->addClass(ZBX_STYLE_BTN_LINK))
		)->setColSpan(3)
	);

	return $url_table;
}

